==> ubuntuone-client_1.4.4.1.orig.tar.gz: ubuntuone-client-1.4.4.1/libsyncdaemon/syncdaemon-publicfiles-interface.h <==
/*
 * Syncdaemon API
 *
 * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
 *
 * Copyright 2010 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __SYNCDAEMON_PUBLICFILES_INTERFACE_H__
#define __SYNCDAEMON_PUBLICFILES_INTERFACE_H__

#include "syncdaemon-daemon.h"
#include "syncdaemon-interface.h"

G_BEGIN_DECLS

#define SYNCDAEMON_TYPE_PUBLICFILES_INTERFACE                (syncdaemon_publicfiles_interface_get_type ())
#define SYNCDAEMON_PUBLICFILES_INTERFACE(obj)                (G_TYPE_CHECK_INSTANCE_CAST ((obj), SYNCDAEMON_TYPE_PUBLICFILES_INTERFACE, SyncdaemonPublicfilesInterface))
#define SYNCDAEMON_IS_PUBLICFILES_INTERFACE(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SYNCDAEMON_TYPE_PUBLICFILES_INTERFACE))
#define SYNCDAEMON_PUBLICFILES_INTERFACE_CLASS(klass)        (G_TYPE_CHECK_CLASS_CAST ((klass), SYNCDAEMON_TYPE_PUBLICFILES_INTERFACE, SyncdaemonPublicfilesInterfaceClass))
#define SYNCDAEMON_IS_PUBLICFILES_INTERFACE_CLASS(klass)     (G_TYPE_CHECK_CLASS_TYPE ((klass), SYNCDAEMON_TYPE_PUBLICFILES_INTERFACE))
#define SYNCDAEMON_PUBLICFILES_INTERFACE_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS ((obj), SYNCDAEMON_TYPE_PUBLICFILES_INTERFACE, SyncdaemonPublicfilesInterfaceClass))

typedef struct _SyncdaemonPublicfilesInterfacePrivate SyncdaemonPublicfilesInterfacePrivate;

typedef struct {
	SyncdaemonInterface parent;
	SyncdaemonPublicfilesInterfacePrivate *priv;
} SyncdaemonPublicfilesInterface;

typedef struct {
	SyncdaemonInterfaceClass parent_class;
} SyncdaemonPublicfilesInterfaceClass;

GType                           syncdaemon_publicfiles_interface_get_type (void);

SyncdaemonPublicfilesInterface *syncdaemon_publicfiles_interface_new (SyncdaemonDaemon *daemon);

void                            syncdaemon_publicfiles_interface_change_public_access (SyncdaemonPublicfilesInterface *interface,
										       const gchar *share_id,
										       const gchar *node_id,
										       gboolean is_public);
void                            syncdaemon_publicfiles_interface_get_public_files (SyncdaemonPublicfilesInterface *interface);

G_END_DECLS

#endif

==> ubuntuone-client_1.6.2.orig.tar.gz: ubuntuone-client-1.6.2/libsyncdaemon/syncdaemon-publicfiles-interface.h <==
/*
 * Syncdaemon API
 *
 * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
 *
 * Copyright 2010 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __SYNCDAEMON_PUBLICFILES_INTERFACE_H__
#define __SYNCDAEMON_PUBLICFILES_INTERFACE_H__

#include "syncdaemon-daemon.h"
#include "syncdaemon-interface.h"

G_BEGIN_DECLS

#define SYNCDAEMON_TYPE_PUBLICFILES_INTERFACE                (syncdaemon_publicfiles_interface_get_type ())
#define SYNCDAEMON_PUBLICFILES_INTERFACE(obj)                (G_TYPE_CHECK_INSTANCE_CAST ((obj), SYNCDAEMON_TYPE_PUBLICFILES_INTERFACE, SyncdaemonPublicfilesInterface))
#define SYNCDAEMON_IS_PUBLICFILES_INTERFACE(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SYNCDAEMON_TYPE_PUBLICFILES_INTERFACE))
#define SYNCDAEMON_PUBLICFILES_INTERFACE_CLASS(klass)        (G_TYPE_CHECK_CLASS_CAST ((klass), SYNCDAEMON_TYPE_PUBLICFILES_INTERFACE, SyncdaemonPublicfilesInterfaceClass))
#define SYNCDAEMON_IS_PUBLICFILES_INTERFACE_CLASS(klass)     (G_TYPE_CHECK_CLASS_TYPE ((klass), SYNCDAEMON_TYPE_PUBLICFILES_INTERFACE))
#define SYNCDAEMON_PUBLICFILES_INTERFACE_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS ((obj), SYNCDAEMON_TYPE_PUBLICFILES_INTERFACE, SyncdaemonPublicfilesInterfaceClass))

typedef struct _SyncdaemonPublicfilesInterfacePrivate SyncdaemonPublicfilesInterfacePrivate;

typedef struct {
	SyncdaemonInterface parent;
	SyncdaemonPublicfilesInterfacePrivate *priv;
} SyncdaemonPublicfilesInterface;

typedef struct {
	SyncdaemonInterfaceClass parent_class;
} SyncdaemonPublicfilesInterfaceClass;

GType                           syncdaemon_publicfiles_interface_get_type (void);

SyncdaemonPublicfilesInterface *syncdaemon_publicfiles_interface_new (SyncdaemonDaemon *daemon);

void                            syncdaemon_publicfiles_interface_change_public_access (SyncdaemonPublicfilesInterface *interface,
										       const gchar *share_id,
										       const gchar *node_id,
										       gboolean is_public);
GSList                         *syncdaemon_publicfiles_interface_get_public_files (SyncdaemonPublicfilesInterface *interface);

G_END_DECLS

#endif
